==> MkImgPage.ver1_2b_20070112.src.zip: MkImgPage.ver1_2b_20070112.src/MkImgPage/MkImgPage/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MkImgPage.rc
//
#define IDR_IEEXTENSION                 101
#define IDD_SETTINGDLG                  102
#define IDS_INIT_IMG_LINK_EXT           103
#define IDS_INIT_IMG_EXT                104
#define IDS_INIT_URL_LINK_EXT           105
#define IDS_INIT_LINK_EXT               106
#define IDS_SYSCMD_HELP                 201
#define IDS_SYSCMD_HELP_URL             202
#define IDS_APP_TITLE                   300
#define IDS_BROWSER_BUSY                301
#define IDS_ERROR_LOADSETTINGS          302
#define IDS_ERROR_SAVESETTINGS          303
#define IDS_ERROR_HRESULT               304
#define IDS_ERROR_UNKNOWN               305
#define IDS_WARNING_TOOMANY_IFRAMES     306
#define IDS_BROWSEROBJ_NOT_FOUND        307
#define IDS_HTMLDOCUMENT_NOT_FOUND      308
#define IDC_RESET                       1000
#define IDS_RESET                       1000
#define IDC_IMG_LINK                    1001
#define IDS_IMG_LINK                    1001
#define IDC_IMG_LINK_EXT                1002
#define IDS_IMG_LINK_EXT                1002
#define IDC_IMG                         1003
#define IDS_IMG                         1003
#define IDC_IMG_EXT                     1004
#define IDS_IMG_EXT                     1004
#define IDC_IMG_SIZE                    1005
#define IDS_IMG_SIZE                    1005
#define IDC_IMG_WIDTH                   1006
#define IDS_IMG_WIDTH                   1006
#define IDC_IMG_HEIGHT                  1007
#define IDS_IMG_HEIGHT                  1007
#define IDC_URL_LINK                    1008
#define IDS_URL_LINK                    1008
#define IDC_URL_LINK_EXT                1009
#define IDS_URL_LINK_EXT                1009
#define IDC_IFRAME_WIDTH                1010
#define IDS_IFRAME_WIDTH                1010
#define IDC_IFRAME_HEIGHT               1011
#define IDS_IFRAME_HEIGHT               1011
#define IDC_LINK                        1012
#define IDS_LINK                        1012
#define IDC_LINK_EXT                    1013
#define IDS_LINK_EXT                    1013
#define IDC_URL                         1016
#define IDS_URL                         1016
#define IDC_URL_LIMIT                   1017
#define IDS_URL_LIMIT                   1017
#define IDC_OPEN_NEW                    1018
#define IDS_OPEN_NEW                    1018
#define IDC_TITLE                       1019
#define IDS_TITLE                       1019
#define IDS_NO_HELP                     9999

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        104
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1021
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> MkImgPage.ver1_2_20070108.src.zip: MkImgPage.ver1_2_20070108.src/MkImgPage/MkImgPage/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MkImgPage.rc
//
#define IDR_IEEXTENSION                 101
#define IDD_SETTINGDLG                  102
#define IDS_INIT_IMG_LINK_EXT           103
#define IDS_INIT_IMG_EXT                104
#define IDS_INIT_URL_LINK_EXT           105
#define IDS_INIT_LINK_EXT               106
#define IDS_INIT_EMBEDDED_EXT           107
#define IDS_SYSCMD_HELP                 201
#define IDS_SYSCMD_HELP_URL             202
#define IDS_APP_TITLE                   300
#define IDS_BROWSER_BUSY                301
#define IDS_ERROR_LOADSETTINGS          302
#define IDS_ERROR_SAVESETTINGS          303
#define IDS_ERROR_HRESULT               304
#define IDS_ERROR_UNKNOWN               305
#define IDS_WARNING_TOOMANY_IFRAMES     306
#define IDC_RESET                       1000
#define IDS_RESET                       1000
#define IDC_IMG_LINK                    1001
#define IDS_IMG_LINK                    1001
#define IDC_IMG_LINK_EXT                1002
#define IDS_IMG_LINK_EXT                1002
#define IDC_IMG                         1003
#define IDS_IMG                         1003
#define IDC_IMG_EXT                     1004
#define IDS_IMG_EXT                     1004
#define IDC_IMG_SIZE                    1005
#define IDS_IMG_SIZE                    1005
#define IDC_IMG_WIDTH                   1006
#define IDS_IMG_WIDTH                   1006
#define IDC_IMG_HEIGHT                  1007
#define IDS_IMG_HEIGHT                  1007
#define IDC_URL_LINK                    1008
#define IDS_URL_LINK                    1008
#define IDC_URL_LINK_EXT                1009
#define IDS_URL_LINK_EXT                1009
#define IDC_IFRAME_WIDTH                1010
#define IDS_IFRAME_WIDTH                1010
#define IDC_IFRAME_HEIGHT               1011
#define IDS_IFRAME_HEIGHT               1011
#define IDC_LINK                        1012
#define IDS_LINK                        1012
#define IDC_LINK_EXT                    1013
#define IDS_LINK_EXT                    1013
#define IDC_EMBEDDED                    1014
#define IDS_EMBEDDED                    1014
#define IDC_EMBEDDED_EXT                1015
#define IDS_EMBEDDED_EXT                1015
#define IDC_URL                         1016
#define IDS_URL                         1016
#define IDC_URL_LIMIT                   1017
#define IDS_URL_LIMIT                   1017
#define IDC_OPEN_NEW                    1018
#define IDS_OPEN_NEW                    1018
#define IDS_NO_HELP                     9999

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        104
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1019
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
